ytree\.tree\_farm\.tree\_farm\.TreeFarm\.trace\_ancestors
=========================================================

.. currentmodule:: ytree.tree_farm.tree_farm

.. automethod:: TreeFarm.trace_ancestors